@@ -27,8 +27,8 @@
 
 import os
 
-VERSION = "2.1.0"
-DATE = "20160327000000"
+VERSION = "2.2.0"
+DATE = "20161220000000"
 NAME = "openshot-qt"
 PRODUCT_NAME = "OpenShot Video Editor"
 GPL_VERSION = "3"
@@ -43,6 +43,7 @@ BACKUP_PATH = os.path.join(USER_PATH, "backup")
 BLENDER_PATH = os.path.join(USER_PATH, "blender")
 THUMBNAIL_PATH = os.path.join(USER_PATH, "thumbnail")
 CACHE_PATH = os.path.join(USER_PATH, "cache")
+PREVIEW_CACHE_PATH = os.path.join(USER_PATH, "preview-cache")
 TITLE_PATH = os.path.join(USER_PATH, "title")
 PROFILES_PATH = os.path.join(PATH, "profiles")
 IMAGES_PATH = os.path.join(PATH, "images")
@@ -53,7 +54,7 @@ USER_PROFILES_PATH = os.path.join(USER_PATH, "profiles")
 
 # Create PATHS if they do not exist (this is where temp files are stored... such as cached thumbnails)
 for folder in [USER_PATH, THUMBNAIL_PATH, CACHE_PATH, BLENDER_PATH, TITLE_PATH, PROFILES_PATH, IMAGES_PATH,
-               TRANSITIONS_PATH, EXPORT_TESTS, BACKUP_PATH, USER_PROFILES_PATH]:
+               TRANSITIONS_PATH, EXPORT_TESTS, BACKUP_PATH, USER_PROFILES_PATH, PREVIEW_CACHE_PATH]:
     if not os.path.exists(folder.encode("UTF-8")):
         os.makedirs(folder, exist_ok=True)
 
