@@ -406,7 +406,7 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
         with open(file_path.encode('UTF-8'), 'rb') as f:
             try:
                 # Unpickle legacy openshot project file
-                v1_data = pickle.load(f, fix_imports=True)
+                v1_data = pickle.load(f, fix_imports=True, encoding="UTF-8")
                 file_lookup = {}
 
                 # Loop through files
@@ -599,7 +599,7 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
 
             except Exception as ex:
                 # Error parsing legacy contents
-                msg = _("Failed to load project file %s: %s" % (file_path, ex))
+                msg = _("Failed to load project file %(path)s: %(error)s" % {"path": file_path, "error": ex})
                 log.error(msg)
                 raise Exception(msg)
 
@@ -642,6 +642,39 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
                     if "handle_right" in point:
                         point["handle_right"]["Y"] = 1.0 - point["handle_right"]["Y"]
 
+        elif openshot_version <= "2.1.0-dev":
+            # Fix handle_left and handle_right coordinates and default to ease in/out bezier curve
+            # using the new percent based keyframes
+            for clip_type in ["clips", "effects"]:
+                for clip in self._data[clip_type]:
+                    for object in [clip] + clip.get('effects',[]):
+                        for item_key, item_data in object.items():
+                            # Does clip attribute have a {"Points": [...]} list
+                            if type(item_data) == dict and "Points" in item_data:
+                                for point in item_data.get("Points"):
+                                    # Convert to percent-based curves
+                                    if "handle_left" in point:
+                                        # Left handle
+                                        point.get("handle_left")["X"] = 0.5
+                                        point.get("handle_left")["Y"] = 1.0
+                                    if "handle_right" in point:
+                                        # Right handle
+                                        point.get("handle_right")["X"] = 0.5
+                                        point.get("handle_right")["Y"] = 0.0
+
+                            elif type(item_data) == dict and "red" in item_data:
+                                for color in ["red", "blue", "green", "alpha"]:
+                                    for point in item_data.get(color).get("Points"):
+                                        # Convert to percent-based curves
+                                        if "handle_left" in point:
+                                            # Left handle
+                                            point.get("handle_left")["X"] = 0.5
+                                            point.get("handle_left")["Y"] = 1.0
+                                        if "handle_right" in point:
+                                            # Right handle
+                                            point.get("handle_right")["X"] = 0.5
+                                            point.get("handle_right")["Y"] = 0.0
+
     def save(self, file_path, move_temp_files=True, make_paths_relative=True):
         """ Save project file to disk """
         import openshot
@@ -748,6 +781,9 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
 
     def add_to_recent_files(self, file_path):
         """ Add this project to the recent files list """
+        if "backup.osp" in file_path:
+            # Ignore backup recovery project
+            return
 
         s = settings.get_settings()
         recent_projects = s.get("recent_projects")
