@@ -37,143 +37,145 @@ App.controller('TimelineCtrl',function($scope) {
 		    num : 24,
 		    den : 1
 		   },
-      duration : 300,				//length of project in seconds
+      duration : 300,			//length of project in seconds
       scale : 16.0,				//seconds per tick
       tick_pixels : 100,		//pixels between tick mark
       playhead_position : 10,	//position of play head
-      clips : [
-	               { 
-	                 id : '1', 
-	                 layer : 1, 
-	                 image : './media/images/thumbnail.png',
-	                 locked : false,
-	                 duration : 32, //max length in seconds
-	                 start : 0,
-	                 end : 32,
-	                 position : 0.0,
-	                 title : 'Clip U2V5ENELDY',
-	                 effects : [
-	                           { type : 'Saturation', icon : 'bw.png'},
-	                           { type : 'ChromaKey',icon : 'om.png'},
-	                           { type : 'Negate',icon : 'neg.png'},
-	                           { type : 'Blur', icon: 'blur.png'},
-	                           { type : 'Brightness', icon: 'cartoon.png'}
-	                           ],
-	                 images :  {start: 1, end: 4},
-	                 show_audio : false,
-
-					 alpha: {
-					    Points: [
-					      {
-					        "interpolation": 2,
-					        "co": {
-					          "Y": 0,
-					          "X": 0
-					        }
-					      },
-					      {
-					        "interpolation": 1,
-					        "co": {
-					          "Y": 0,
-					          "X": 250
-					        }
-					      },
-					      {
-					        "interpolation": 1,
-					        "co": {
-					          "Y": 1,
-					          "X": 500
-					        }
-					      }
-						]
-					},
-					location_x: { Points: [] },
-					location_y: { Points: [] },
-					scale_x: { Points: [] },
-					scale_y: { Points: [] },
-					rotation: { Points: [] },
-					time: { Points: [] },
-					volume: { Points: [] }
-	                 
-	               },
-	               {
-	                 id : '2', 
-	                 layer : 2, 
-	                 image : './media/images/thumbnail.png',
-	                 locked : false,
-	                 duration : 45,
-	                 start : 0,
-	                 end : 45,
-	                 position : 0.0,
-	                 title : 'Clip B',
-	                 effects : [],
-	                 images : {start: 3, end: 7},
-	                 show_audio : false,
-	                 alpha: { Points: [] },
-	                 location_x: { Points: [] },
-					 location_y: { Points: [] },
-					 scale_x: { Points: [] },
-					 scale_y: { Points: [] },
-					 rotation: { Points: [] },
-					 time: { Points: [] },
-					 volume: { Points: [] }
-	               },
-	               {
-	                 id : '3', 
-	                 layer : 3, 
-	                 image : './media/images/thumbnail.png',
-	                 locked : false,
-	                 duration : 120,
-	                 start : 0,
-	                 end : 120,
-	                 position : 32.0,
-	                 title : 'Clip C',
-	                 effects : [
-	                           { type : 'Deinterlace',icon : 'om.png'},
-	                           { type : 'Blur', icon: 'blur.png'},
-	                           { type : 'Mask', icon: 'cartoon.png'}
-	                           ],
-	                 images : { start: 5, end: 10 },
-	                 show_audio : false,
-	                 audio_data : [.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3, ],
-	                 alpha: { Points: [] },
-	                 location_x: { Points: [] },
-					 location_y: { Points: [] },
-					 scale_x: { Points: [] },
-					 scale_y: { Points: [] },
-					 rotation: { Points: [] },
-					 time: { Points: [] },
-					 volume: { Points: [] }
-	               },
-             ],
+      clips : [],
+		  	// [
+	          //      {
+	          //        id : '1',
+	          //        layer : 1,
+	          //        image : './media/images/thumbnail.png',
+	          //        locked : false,
+	          //        duration : 32, //max length in seconds
+	          //        start : 0,
+	          //        end : 32,
+	          //        position : 0.0,
+	          //        title : 'Clip U2V5ENELDY',
+	          //        effects : [
+	          //                  { type : 'Saturation', icon : 'bw.png'},
+	          //                  { type : 'ChromaKey',icon : 'om.png'},
+	          //                  { type : 'Negate',icon : 'neg.png'},
+	          //                  { type : 'Blur', icon: 'blur.png'},
+	          //                  { type : 'Brightness', icon: 'cartoon.png'}
+	          //                  ],
+	          //        images :  {start: 1, end: 4},
+	          //        show_audio : false,
+             //
+				// 	 alpha: {
+				// 	    Points: [
+				// 	      {
+				// 	        "interpolation": 2,
+				// 	        "co": {
+				// 	          "Y": 0,
+				// 	          "X": 0
+				// 	        }
+				// 	      },
+				// 	      {
+				// 	        "interpolation": 1,
+				// 	        "co": {
+				// 	          "Y": 0,
+				// 	          "X": 250
+				// 	        }
+				// 	      },
+				// 	      {
+				// 	        "interpolation": 1,
+				// 	        "co": {
+				// 	          "Y": 1,
+				// 	          "X": 500
+				// 	        }
+				// 	      }
+				// 		]
+				// 	},
+				// 	location_x: { Points: [] },
+				// 	location_y: { Points: [] },
+				// 	scale_x: { Points: [] },
+				// 	scale_y: { Points: [] },
+				// 	rotation: { Points: [] },
+				// 	time: { Points: [] },
+				// 	volume: { Points: [] }
+	          //
+	          //      },
+	          //      {
+	          //        id : '2',
+	          //        layer : 2,
+	          //        image : './media/images/thumbnail.png',
+	          //        locked : false,
+	          //        duration : 45,
+	          //        start : 0,
+	          //        end : 45,
+	          //        position : 0.0,
+	          //        title : 'Clip B',
+	          //        effects : [],
+	          //        images : {start: 3, end: 7},
+	          //        show_audio : false,
+	          //        alpha: { Points: [] },
+	          //        location_x: { Points: [] },
+				// 	 location_y: { Points: [] },
+				// 	 scale_x: { Points: [] },
+				// 	 scale_y: { Points: [] },
+				// 	 rotation: { Points: [] },
+				// 	 time: { Points: [] },
+				// 	 volume: { Points: [] }
+	          //      },
+	          //      {
+	          //        id : '3',
+	          //        layer : 3,
+	          //        image : './media/images/thumbnail.png',
+	          //        locked : false,
+	          //        duration : 120,
+	          //        start : 0,
+	          //        end : 120,
+	          //        position : 32.0,
+	          //        title : 'Clip C',
+	          //        effects : [
+	          //                  { type : 'Deinterlace',icon : 'om.png'},
+	          //                  { type : 'Blur', icon: 'blur.png'},
+	          //                  { type : 'Mask', icon: 'cartoon.png'}
+	          //                  ],
+	          //        images : { start: 5, end: 10 },
+	          //        show_audio : false,
+	          //        audio_data : [.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3,.5, .6, .7, .7, .6, .5, .4, .1, 0, -0.1, -0.3, -0.6, -0.6, -0.3, -0.1, 0, .2, .3, ],
+	          //        alpha: { Points: [] },
+	          //        location_x: { Points: [] },
+				// 	 location_y: { Points: [] },
+				// 	 scale_x: { Points: [] },
+				// 	 scale_y: { Points: [] },
+				// 	 rotation: { Points: [] },
+				// 	 time: { Points: [] },
+				// 	 volume: { Points: [] }
+	          //      },
+             // ],
              
-	  effects : [
-	                	{
-	   	                 id : '5', 
-		                 layer : 4, 
-		                 title : 'Transition',
-		                 position : 20.0,
-		                 start : 0,
-		                 end : 30
-	                	},
-	                	{
-	   	                 id : '6', 
-		                 layer : 3, 
-		                 title : 'Transition',
-		                 position : 137.5,
-		                 start : 0,
-		                 end : 30
-	                	},
-	                	{
-	   	                 id : '7',
-		                 layer : 2,
-		                 title : 'Transition',
-		                 position : 30.5,
-		                 start : 0,
-		                 end : 30
-	                	}
-                    
-                    ],
+	  effects : [],
+		  		// [
+	               //  	{
+	   	        //          id : '5',
+		           //       layer : 4,
+		           //       title : 'Transition',
+		           //       position : 20.0,
+		           //       start : 0,
+		           //       end : 30
+	               //  	},
+	               //  	{
+	   	        //          id : '6',
+		           //       layer : 3,
+		           //       title : 'Transition',
+		           //       position : 137.5,
+		           //       start : 0,
+		           //       end : 30
+	               //  	},
+	               //  	{
+	   	        //          id : '7',
+		           //       layer : 2,
+		           //       title : 'Transition',
+		           //       position : 30.5,
+		           //       start : 0,
+		           //       end : 30
+	               //  	}
+                   //
+                   //  ],
              
 	  layers : [
 	  				{id: 'L0', number:0, y:0, label: '', lock: false},
@@ -184,34 +186,49 @@ App.controller('TimelineCtrl',function($scope) {
 	  				
              ],
              
-	  markers : [
-	                {
-	                  id : 'M1',
-	                  position : 16,
-	                  icon : 'yellow.png'
-	                },
-	                {
-	                  id : 'M2',
-	                  position: 120,
-	                  icon : 'green.png'
-	                },
-	                {
-	                  id : 'M3',
-	                  position: 300,
-	                  icon : 'red.png'
-	                },
-	                {
-	                  id : 'M4',
-	                  position: 10,
-	                  icon : 'purple.png'
-	                },
-              ],
+	  markers : [],
+              // [
+	           //      {
+	           //        id : 'M1',
+	           //        position : 16,
+	           //        icon : 'yellow.png'
+	           //      },
+	           //      {
+	           //        id : 'M2',
+	           //        position: 120,
+	           //        icon : 'green.png'
+	           //      },
+	           //      {
+	           //        id : 'M3',
+	           //        position: 300,
+	           //        icon : 'red.png'
+	           //      },
+	           //      {
+	           //        id : 'M4',
+	           //        position: 10,
+	           //        icon : 'purple.png'
+	           //      },
+              // ],
               
-	  progress : [
-	                  [0, 30, 'rendering'],
-	                  [40, 50, 'complete'],
-	                  [100, 150, 'complete'],
-                  ]
+	  progress : {}
+	  			// {
+				//    max_bytes : "0",
+				//    ranges : [
+				// 	  {
+				// 		 end : "30",
+				// 		 start : "0"
+				// 	  },
+				// 	  {
+				// 		 end : "40",
+				// 		 start : "50"
+				// 	  },
+				// 	  {
+				// 		 end : "100",
+				// 		 start : "150"
+				// 	  }
+				//    ],
+				//    version : "2"
+				// }
     };
   
   // Additional variables used to control the rendering of HTML
@@ -234,10 +251,6 @@ App.controller('TimelineCtrl',function($scope) {
   $scope.Qt = false;
   $scope.EnableQt = function() { 
 	  	$scope.Qt = true;
-	  	$scope.project.clips = [];
-	  	$scope.project.markers = [];
-	  	$scope.project.effects = [];
-	  	$scope.project.progress = [];
 	  	timeline.qt_log("$scope.Qt = true;"); 
   };
 
@@ -314,6 +327,15 @@ App.controller('TimelineCtrl',function($scope) {
 					// Only add keyframe coordinates that are within the bounds of the clip
 					keyframes[co.X] = co.Y;
 			}
+
+	    // Determine if this property is a Color Keyframe
+	 	if (typeof object[child] == "object" && "red" in object[child])
+			for (var point = 0; point < object[child]["red"].Points.length; point++) {
+				var co = object[child]["red"].Points[point].co;
+				if (co.X >= clip_start_x && co.X <= clip_end_x)
+					// Only add keyframe coordinates that are within the bounds of the clip
+					keyframes[co.X] = co.Y;
+			}
 	}
 
 	// Determine if this property contains effects (i.e. clips have their own effects)
@@ -335,6 +357,15 @@ App.controller('TimelineCtrl',function($scope) {
 							// Only add keyframe coordinates that are within the bounds of the clip
 							keyframes[co.X] = co.Y;
 					}
+
+				// Determine if this property is a Color Keyframe
+				if (typeof object["effects"][effect][child] == "object" && "red" in object["effects"][effect][child])
+					for (var point = 0; point < object["effects"][effect][child]["red"].Points.length; point++) {
+						var co = object["effects"][effect][child]["red"].Points[point].co;
+						if (co.X >= clip_start_x && co.X <= clip_end_x)
+							// Only add keyframe coordinates that are within the bounds of the clip
+							keyframes[co.X] = co.Y;
+					}
 			}
 		}
 	
@@ -474,6 +505,41 @@ App.controller('TimelineCtrl',function($scope) {
 	 });
  };
 	
+ // Update cache json
+ $scope.RenderCache = function(cache_json){
+
+	 // Push new clip onto stack
+	 $scope.project.progress = cache_json;
+	 
+	//clear the canvas first
+	var ruler = $("#progress");
+	var ctx = ruler[0].getContext('2d');
+	ctx.clearRect(0, 0, ruler.width(), ruler.height());
+
+	// Determine fps & and get cached ranges
+	var fps = $scope.project.fps.num / $scope.project.fps.den;
+	var progress = $scope.project.progress.ranges;
+
+	// Loop through each cached range of frames, and draw rect
+	for(p=0;p<progress.length;p++) {
+
+		//get the progress item details
+		var start_second = parseFloat(progress[p]["start"]) / fps;
+		var stop_second = parseFloat(progress[p]["end"]) / fps;
+
+		//figure out the actual pixel position
+		var start_pixel = start_second * $scope.pixelsPerSecond;
+		var stop_pixel = stop_second * $scope.pixelsPerSecond;
+		var rect_length = stop_pixel - start_pixel;
+
+		//get the element and draw the rects
+		ctx.beginPath();
+		ctx.rect(start_pixel, 0, rect_length, 5);
+		ctx.fillStyle = '#4B92AD';
+		ctx.fill();
+	}
+ };	
+	
  // Clear all selections
  $scope.ClearAllSelections = function() {
 	// Clear the selections on the main window
@@ -695,11 +761,12 @@ $scope.SetTrackLabel = function (label){
  // Get Track number of item (used by Qt)
  $scope.GetJavaScriptTrack = function(y){
 	// Adjust for scrollbar position
+	var scrolling_tracks_offset_top = $("#scrolling_tracks").offset().top;
   	var vert_scroll_offset = $("#scrolling_tracks").scrollTop();
 	y += vert_scroll_offset;
 
 	// Return number of track
-	var track_number = parseInt($scope.GetTrackAtY(y).number);
+	var track_number = parseInt($scope.GetTrackAtY(y - scrolling_tracks_offset_top).number);
 	return track_number;
  };
  
@@ -741,6 +808,14 @@ $scope.SetTrackLabel = function (label){
 	// Hide snapline (if any)
 	$scope.HideSnapline();
 
+	// Check again for missing transitions
+	missing_transition_details = $scope.GetMissingTransitions(item_object);
+	if ($scope.Qt && missing_transition_details != null)
+		timeline.add_missing_transition(JSON.stringify(missing_transition_details));
+
+	// Remove manual move stylesheet
+	bounding_box.element.removeClass("manual-move");
+
 	// Remove CSS class (after the drag)
 	bounding_box = {};
  };
@@ -769,6 +844,10 @@ $scope.SetTrackLabel = function (label){
 	 bounding_box.offset_y = 0;
 	 bounding_box.element = $(element_id);
 	 bounding_box.track_position = 0;
+
+	 // Set z-order to be above other clips/transitions
+	 if (item_type != "os_drop")
+	 	bounding_box.element.addClass("manual-move");
  };
  
  // Move a new clip to the timeline
