@@ -28,6 +28,7 @@
  """
 
 import os
+import platform
 import shutil
 import webbrowser
 from uuid import uuid4
@@ -84,7 +85,7 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         self.tutorial_manager.exit_manager()
 
         # Prompt user to save (if needed)
-        if get_app().project.needs_save():
+        if get_app().project.needs_save() and not self.mode == "unittest":
             log.info('Prompt user to save project')
             # Translate object
             _ = get_app()._tr
@@ -144,9 +145,6 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
             msg.setWindowTitle(_("Backup Recovered"))
             msg.setText(_("Your most recent unsaved project has been recovered."))
             msg.exec_()
-        else:
-            # Load a blank project (to propagate the default settings)
-            get_app().project.load("")
 
     def create_lock_file(self):
         """Create a lock file"""
@@ -157,18 +155,53 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         if os.path.exists(lock_path):
             # Walk the libopenshot log (if found), and try and find last line before this launch
             log_path = os.path.join(info.USER_PATH, "libopenshot.log")
-            last_log_line = None
+            last_log_line = ""
+            last_stack_trace = ""
+            found_stack = False
+            log_start_counter = 0
             if os.path.exists(log_path):
                 with open(log_path, "r") as f:
                     # Read from bottom up
                     for line in reversed(f.readlines()):
+                        # Detect stack trace
+                        if "End of Stack Trace" in line:
+                            found_stack = True
+                            continue
+                        elif "Unhandled Exception: Stack Trace" in line:
+                            found_stack = False
+                            continue
+                        elif "libopenshot logging:" in line:
+                            log_start_counter += 1
+                            if log_start_counter > 1:
+                                # Found the previous log start, too old now
+                                break
+
+                        if found_stack:
+                            # Append line to beginning of stacktrace
+                            last_stack_trace = line + last_stack_trace
+
                         # Ignore certain unuseful lines
-                        if "---" not in line and "libopenshot logging:" not in line:
+                        if line.strip() and "---" not in line and "libopenshot logging:" not in line and not last_log_line:
                             last_log_line = line
-                            break
+
+            # Split last stack trace (if any)
+            if last_stack_trace:
+                # Get top line of stack trace (for metrics)
+                last_log_line = last_stack_trace.split("\n")[0].strip()
+
+                # Send stacktrace for debugging (if send metrics is enalbed)
+                track_exception_stacktrace(last_stack_trace, "libopenshot")
 
             # Clear / normalize log line (so we can roll them up in the analytics)
             if last_log_line:
+                # Format last log line based on OS (since each OS can be formatted differently)
+                if platform.system() == "Darwin":
+                    last_log_line = "mac-%s" % last_log_line[58:].strip()
+                elif platform.system() == "Windows":
+                    last_log_line = "windows-%s" % last_log_line
+                elif platform.system() == "Linux":
+                    last_log_line = "linux-%s" % last_log_line.replace("/usr/local/lib/", "")
+
                 # Remove '()' from line, and split. Trying to grab the beginning of the log line.
                 last_log_line = last_log_line.replace("()", "")
                 log_parts = last_log_line.split("(")
@@ -497,12 +530,23 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         app = get_app()
         app.updates.undo()
 
+        # Update the preview
+        self.refreshFrameSignal.emit()
+
     def actionRedo_trigger(self, event):
         log.info('actionRedo_trigger')
         app = get_app()
         app.updates.redo()
 
+        # Update the preview
+        self.refreshFrameSignal.emit()
+
     def actionPreferences_trigger(self, event):
+        # Stop preview thread
+        self.SpeedSignal.emit(0)
+        ui_util.setup_icon(self, self.actionPlay, "actionPlay", "media-playback-start")
+        self.actionPlay.setChecked(False)
+
         # Show dialog
         from windows.preferences import Preferences
         win = Preferences()
@@ -513,6 +557,10 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         else:
             log.info('Preferences add cancelled')
 
+        # Save settings
+        s = settings.get_settings()
+        s.save()
+
     def actionFilesShowAll_trigger(self, event):
         self.filesTreeView.refresh_view()
 
@@ -654,6 +702,10 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         # Notify properties dialog
         self.propertyTableView.select_frame(position_frames)
 
+    def handlePausedVideo(self):
+        """Handle the pause signal, by refreshing the properties dialog"""
+        self.propertyTableView.select_frame(self.preview_thread.player.Position())
+
     def movePlayhead(self, position_frames):
         """Update playhead position"""
         # Notify preview thread
@@ -1308,6 +1360,10 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         app = get_app()
         s = settings.get_settings()
 
+        # Prepare treeview for deletion
+        if self.filesTreeView:
+            self.filesTreeView.prepare_for_delete()
+
         # Files
         if app.context_menu_object == "files":
             s.set("file_view", "details")
@@ -1342,6 +1398,10 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         app = get_app()
         s = settings.get_settings()
 
+        # Prepare treeview for deletion
+        if self.filesTreeView:
+            self.filesTreeView.prepare_for_delete()
+
         # Files
         if app.context_menu_object == "files":
             s.set("file_view", "thumbnail")
@@ -1702,8 +1762,8 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
 
         # Setup Zoom slider
         self.sliderZoom = QSlider(Qt.Horizontal, self)
-        self.sliderZoom.setPageStep(6)
-        self.sliderZoom.setRange(8, 800)
+        self.sliderZoom.setPageStep(2)
+        self.sliderZoom.setRange(1, 800)
         self.sliderZoom.setValue(20)
         self.sliderZoom.setInvertedControls(True)
         self.sliderZoom.resize(100, 16)
@@ -1776,10 +1836,45 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
                 if shortcut.get('setting') == action.objectName():
                     action.setShortcut(QKeySequence(_(shortcut.get('value'))))
 
-    def __init__(self):
+    def InitCacheSettings(self):
+        """Set the correct cache settings for the timeline"""
+        # Load user settings
+        s = settings.get_settings()
+        log.info("InitCacheSettings")
+        log.info("cache-mode: %s" % s.get("cache-mode"))
+        log.info("cache-limit-mb: %s" % s.get("cache-limit-mb"))
+
+        # Get MB limit of cache (and convert to bytes)
+        cache_limit = s.get("cache-limit-mb") * 1024 * 1024 # Convert MB to Bytes
+
+        # Clear old cache
+        new_cache_object = None
+        if s.get("cache-mode") == "CacheMemory":
+            # Create CacheMemory object, and set on timeline
+            log.info("Creating CacheMemory object with %s byte limit" % cache_limit)
+            new_cache_object = openshot.CacheMemory(cache_limit)
+            self.timeline_sync.timeline.SetCache(new_cache_object)
+
+        elif s.get("cache-mode") == "CacheDisk":
+            # Create CacheDisk object, and set on timeline
+            log.info("Creating CacheDisk object with %s byte limit at %s" % (cache_limit, info.PREVIEW_CACHE_PATH))
+            image_format = s.get("cache-image-format")
+            image_quality = s.get("cache-quality")
+            image_scale = s.get("cache-scale")
+            new_cache_object = openshot.CacheDisk(info.PREVIEW_CACHE_PATH, image_format, image_quality, image_scale, cache_limit)
+            self.timeline_sync.timeline.SetCache(new_cache_object)
+
+        # Clear old cache before it goes out of scope
+        if self.cache_object:
+            self.cache_object.Clear()
+        # Update cache reference, so it doesn't go out of scope
+        self.cache_object = new_cache_object
+
+    def __init__(self, mode=None):
 
         # Create main window base class
         QMainWindow.__init__(self)
+        self.mode = mode    # None or unittest (None is normal usage)
 
         # set window on app for reference during initialization of children
         get_app().window = self
@@ -1816,7 +1911,11 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         get_current_Version()
 
         # Connect signals
-        self.RecoverBackup.connect(self.recover_backup)
+        if not self.mode == "unittest":
+            self.RecoverBackup.connect(self.recover_backup)
+
+        # Create the timeline sync object (used for previewing timeline)
+        self.timeline_sync = TimelineSync(self)
 
         # Setup timeline
         self.timeline = TimelineWebView(self)
@@ -1863,14 +1962,18 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         # Load window state and geometry
         self.load_settings()
 
-        # Create the timeline sync object (used for previewing timeline)
-        self.timeline_sync = TimelineSync(self)
+        # Setup Cache settings
+        self.cache_object = None
+        self.InitCacheSettings()
 
         # Start the preview thread
         self.preview_parent = PreviewParent()
         self.preview_parent.Init(self, self.timeline_sync.timeline, self.videoPreview)
         self.preview_thread = self.preview_parent.worker
 
+        # Set pause callback
+        self.PauseSignal.connect(self.handlePausedVideo)
+
         # QTimer for Autosave
         self.auto_save_timer = QTimer(self)
         self.auto_save_timer.setInterval(s.get("autosave-interval") * 1000 * 60)
@@ -1882,7 +1985,8 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         self.create_lock_file()
 
         # Show window
-        self.show()
+        if not self.mode == "unittest":
+            self.show()
 
         # Create tutorial manager
         self.tutorial_manager = TutorialManager(self)
