@@ -131,6 +131,9 @@ class PropertiesModel(updates.UpdateInterface):
             self.selected.append((e, item_type))
 
 
+        # Update frame # from timeline
+        self.update_frame(get_app().window.preview_thread.player.Position(), reload_model=False)
+
         # Get ID of item
         self.new_item = True
 
@@ -138,7 +141,7 @@ class PropertiesModel(updates.UpdateInterface):
         self.update_model(get_app().window.txtPropertyFilter.text())
 
     # Update the values of the selected clip, based on the current frame
-    def update_frame(self, frame_number):
+    def update_frame(self, frame_number, reload_model=True):
 
         # Check for a selected clip
         if self.selected:
@@ -185,7 +188,8 @@ class PropertiesModel(updates.UpdateInterface):
             log.info("Update frame to %s" % self.frame_number)
 
             # Update the model data
-            self.update_model(get_app().window.txtPropertyFilter.text())
+            if reload_model:
+                self.update_model(get_app().window.txtPropertyFilter.text())
 
     def remove_keyframe(self, item):
         """Remove an existing keyframe (if any)"""
@@ -265,13 +269,14 @@ class PropertiesModel(updates.UpdateInterface):
                 # Clear selection
                 self.parent.clearSelection()
 
-    def color_update(self, item, new_color, interpolation=-1):
+    def color_update(self, item, new_color, interpolation=-1, interpolation_details=[]):
         """Insert/Update a color keyframe for the selected row"""
 
         # Determine what was changed
         property = self.model.item(item.row(), 0).data()
         property_type = property[1]["type"]
         closest_point_x = property[1]["closest_point_x"]
+        previous_point_x = property[1]["previous_point_x"]
         property_key = property[0]
         clip_id, item_type = item.data()
 
@@ -312,13 +317,31 @@ class PropertiesModel(updates.UpdateInterface):
                                 log.info("updating point: co.X = %s to value: %s" % (point["co"]["X"], float(new_value)))
                                 break
 
-                            elif interpolation > -1 and point["co"]["X"] == closest_point_x:
-                                # Only update interpolation type
+                            elif interpolation > -1 and point["co"]["X"] == previous_point_x:
+                                # Only update interpolation type (and the LEFT side of the curve)
                                 found_point = True
                                 clip_updated = True
                                 point["interpolation"] = interpolation
+                                if interpolation == 0:
+                                    point["handle_right"] = point.get("handle_right") or {"Y": 0.0, "X": 0.0}
+                                    point["handle_right"]["X"] = interpolation_details[0]
+                                    point["handle_right"]["Y"] = interpolation_details[1]
+
                                 log.info("updating interpolation mode point: co.X = %s to %s" % (point["co"]["X"], interpolation))
-                                break
+                                log.info("use interpolation preset: %s" % str(interpolation_details))
+
+                            elif interpolation > -1 and point["co"]["X"] == closest_point_x:
+                                # Only update interpolation type (and the RIGHT side of the curve)
+                                found_point = True
+                                clip_updated = True
+                                point["interpolation"] = interpolation
+                                if interpolation == 0:
+                                    point["handle_left"] = point.get("handle_left") or {"Y": 0.0, "X": 0.0}
+                                    point["handle_left"]["X"] = interpolation_details[2]
+                                    point["handle_left"]["Y"] = interpolation_details[3]
+
+                                log.info("updating interpolation mode point: co.X = %s to %s" % (point["co"]["X"], interpolation))
+                                log.info("use interpolation preset: %s" % str(interpolation_details))
 
                         # Create new point (if needed)
                         if not found_point:
@@ -340,7 +363,7 @@ class PropertiesModel(updates.UpdateInterface):
                 # Clear selection
                 self.parent.clearSelection()
 
-    def value_updated(self, item, interpolation=-1, value=None):
+    def value_updated(self, item, interpolation=-1, value=None, interpolation_details=[]):
         """ Table cell change event - also handles context menu to update interpolation value """
 
         if self.ignore_update_signal:
@@ -353,6 +376,7 @@ class PropertiesModel(updates.UpdateInterface):
         property = self.model.item(item.row(), 0).data()
         property_name = property[1]["name"]
         closest_point_x = property[1]["closest_point_x"]
+        previous_point_x = property[1]["previous_point_x"]
         property_type = property[1]["type"]
         property_key = property[0]
         clip_id, item_type = item.data()
@@ -423,13 +447,31 @@ class PropertiesModel(updates.UpdateInterface):
                                 point_to_delete = point
                             break
 
-                        elif interpolation > -1 and point["co"]["X"] == closest_point_x:
-                            # Only update interpolation type
+                        elif interpolation > -1 and point["co"]["X"] == previous_point_x:
+                            # Only update interpolation type (and the LEFT side of the curve)
                             found_point = True
                             clip_updated = True
                             point["interpolation"] = interpolation
+                            if interpolation == 0:
+                                point["handle_right"] = point.get("handle_right") or {"Y": 0.0, "X": 0.0}
+                                point["handle_right"]["X"] = interpolation_details[0]
+                                point["handle_right"]["Y"] = interpolation_details[1]
+
                             log.info("updating interpolation mode point: co.X = %s to %s" % (point["co"]["X"], interpolation))
-                            break
+                            log.info("use interpolation preset: %s" % str(interpolation_details))
+
+                        elif interpolation > -1 and point["co"]["X"] == closest_point_x:
+                            # Only update interpolation type (and the RIGHT side of the curve)
+                            found_point = True
+                            clip_updated = True
+                            point["interpolation"] = interpolation
+                            if interpolation == 0:
+                                point["handle_left"] = point.get("handle_left") or {"Y": 0.0, "X": 0.0}
+                                point["handle_left"]["X"] = interpolation_details[2]
+                                point["handle_left"]["Y"] = interpolation_details[3]
+
+                            log.info("updating interpolation mode point: co.X = %s to %s" % (point["co"]["X"], interpolation))
+                            log.info("use interpolation preset: %s" % str(interpolation_details))
 
                     # Delete point (if needed)
                     if point_to_delete:
