@@ -26,6 +26,7 @@
  """
 
 import os
+from functools import partial
 from PyQt5.QtCore import Qt, QRectF, QLocale, pyqtSignal, Qt, QObject, QTimer
 from PyQt5.QtGui import *
 from PyQt5.QtWidgets import QTableView, QAbstractItemView, QMenu, QSizePolicy, QHeaderView, QColorDialog, QItemDelegate, QStyle, QLabel, QPushButton, QHBoxLayout, QFrame
@@ -171,17 +172,41 @@ class PropertiesTableView(QTableView):
             cursor_value_percent = cursor_value / self.columnWidth(1)
 
             property = self.selected_label.data()
+            property_key = property[0]
             property_name = property[1]["name"]
             property_type = property[1]["type"]
             property_max = property[1]["max"]
             property_min = property[1]["min"]
             property_value = property[1]["value"]
             readonly = property[1]["readonly"]
+            item_id, item_type = self.selected_item.data()
 
             # Bail if readonly
             if readonly:
                 return
 
+            # Get the original data of this item (prior to any updates, for the undo/redo system)
+            if not self.original_data:
+                # Ignore undo/redo history temporarily (to avoid a huge pile of undo/redo history)
+                get_app().updates.ignore_history = True
+
+                # Find this clip
+                c = None
+                if item_type == "clip":
+                    # Get clip object
+                    c = Clip.get(id=item_id)
+                elif item_type == "transition":
+                    # Get transition object
+                    c = Transition.get(id=item_id)
+                elif item_type == "effect":
+                    # Get effect object
+                    c = Effect.get(id=item_id)
+
+                if c:
+                    if property_key in c.data:
+                        # Grab the original data for this item/property
+                        self.original_data = c.data
+
             # Calculate percentage value
             if property_type in ["float", "int"]:
                 min_max_range = float(property_max) - float(property_min)
@@ -189,7 +214,7 @@ class PropertiesTableView(QTableView):
                 # Determine if range is unreasonably long (such as position, start, end, etc.... which can be huge #'s)
                 if min_max_range > 1000.0:
                     # Get the current value
-                    new_value = QLocale().system().toDouble(self.selected_item.text())[0]
+                    self.new_value = QLocale().system().toDouble(self.selected_item.text())[0]
 
                     # Huge range - increment / decrement slowly
                     if self.previous_x == -1:
@@ -199,28 +224,37 @@ class PropertiesTableView(QTableView):
                     drag_diff = self.previous_x - event.x()
                     if drag_diff > 0:
                         # Move to the left by a small amount
-                        new_value -= 0.50
+                        self.new_value -= 0.50
                     elif drag_diff < 0:
                         # Move to the right by a small amount
-                        new_value += 0.50
+                        self.new_value += 0.50
                     # update previous x
                     self.previous_x = event.x()
                 else:
                     # Small range - use cursor % to calculate new value
-                    new_value = property_min + (min_max_range * cursor_value_percent)
+                    self.new_value = property_min + (min_max_range * cursor_value_percent)
 
                 # Clamp value between min and max (just incase user drags too big)
-                new_value = max(property_min, new_value)
-                new_value = min(property_max, new_value)
+                self.new_value = max(property_min, self.new_value)
+                self.new_value = min(property_max, self.new_value)
 
                 # Update value of this property
-                self.clip_properties_model.value_updated(self.selected_item, -1, new_value)
+                self.clip_properties_model.value_updated(self.selected_item, -1, self.new_value)
 
                 # Repaint
                 self.viewport().update()
 
+    def mouseReleaseEvent(self, event):
+        # Inform UpdateManager to accept updates, and only store our final update
+        get_app().updates.ignore_history = False
 
-    def double_click(self, model_index):
+        # Add final update to undo/redo history
+        get_app().updates.apply_last_action_to_history(self.original_data)
+
+        # Clear original data
+        self.original_data = None
+
+    def doubleClickedCB(self, model_index):
         """Double click handler for the property table"""
         # Get data model and selection
         model = self.clip_properties_model.model
@@ -295,6 +329,41 @@ class PropertiesTableView(QTableView):
             log.info("Points: %s" % points)
             log.info("Property: %s" % str(property))
 
+            # Define bezier presets
+            bezier_presets = [
+                (0.250, 0.100, 0.250, 1.000, _("Ease (Default)")),
+                (0.420, 0.000, 1.000, 1.000, _("Ease In")),
+                (0.000, 0.000, 0.580, 1.000, _("Ease Out")),
+                (0.420, 0.000, 0.580, 1.000, _("Ease In/Out")),
+
+                (0.550, 0.085, 0.680, 0.530, _("Ease In (Quad)")),
+                (0.550, 0.055, 0.675, 0.190, _("Ease In (Cubic)")),
+                (0.895, 0.030, 0.685, 0.220, _("Ease In (Quart)")),
+                (0.755, 0.050, 0.855, 0.060, _("Ease In (Quint)")),
+                (0.470, 0.000, 0.745, 0.715, _("Ease In (Sine)")),
+                (0.950, 0.050, 0.795, 0.035, _("Ease In (Expo)")),
+                (0.600, 0.040, 0.980, 0.335, _("Ease In (Circ)")),
+                (0.600, -0.280, 0.735, 0.045, _("Ease In (Back)")),
+
+                (0.250, 0.460, 0.450, 0.940, _("Ease Out (Quad)")),
+                (0.215, 0.610, 0.355, 1.000, _("Ease Out (Cubic)")),
+                (0.165, 0.840, 0.440, 1.000, _("Ease Out (Quart)")),
+                (0.230, 1.000, 0.320, 1.000, _("Ease Out (Quint)")),
+                (0.390, 0.575, 0.565, 1.000, _("Ease Out (Sine)")),
+                (0.190, 1.000, 0.220, 1.000, _("Ease Out (Expo)")),
+                (0.075, 0.820, 0.165, 1.000, _("Ease Out (Circ)")),
+                (0.175, 0.885, 0.320, 1.275, _("Ease Out (Back)")),
+
+                (0.455, 0.030, 0.515, 0.955, _("Ease In/Out (Quad)")),
+                (0.645, 0.045, 0.355, 1.000, _("Ease In/Out (Cubic)")),
+                (0.770, 0.000, 0.175, 1.000, _("Ease In/Out (Quart)")),
+                (0.860, 0.000, 0.070, 1.000, _("Ease In/Out (Quint)")),
+                (0.445, 0.050, 0.550, 0.950, _("Ease In/Out (Sine)")),
+                (1.000, 0.000, 0.000, 1.000, _("Ease In/Out (Expo)")),
+                (0.785, 0.135, 0.150, 0.860, _("Ease In/Out (Circ)")),
+                (0.680, -0.550, 0.265, 1.550, _("Ease In/Out (Back)"))
+            ]
+
             bezier_icon = QIcon(QPixmap(os.path.join(info.IMAGES_PATH, "keyframe-%s.png" % openshot.BEZIER)))
             linear_icon = QIcon(QPixmap(os.path.join(info.IMAGES_PATH, "keyframe-%s.png" % openshot.LINEAR)))
             constant_icon = QIcon(QPixmap(os.path.join(info.IMAGES_PATH, "keyframe-%s.png" % openshot.CONSTANT)))
@@ -303,9 +372,12 @@ class PropertiesTableView(QTableView):
             menu = QMenu(self)
             if points > 1:
                 # Menu for more than 1 point
-                Bezier_Action = menu.addAction(_("Bezier"))
-                Bezier_Action.setIcon(bezier_icon)
-                Bezier_Action.triggered.connect(self.Bezier_Action_Triggered)
+                Bezier_Menu = QMenu(_("Bezier"), self)
+                Bezier_Menu.setIcon(bezier_icon)
+                for bezier_preset in bezier_presets:
+                    preset_action = Bezier_Menu.addAction(bezier_preset[4])
+                    preset_action.triggered.connect(partial(self.Bezier_Action_Triggered, bezier_preset))
+                menu.addMenu(Bezier_Menu)
                 Linear_Action = menu.addAction(_("Linear"))
                 Linear_Action.setIcon(linear_icon)
                 Linear_Action.triggered.connect(self.Linear_Action_Triggered)
@@ -331,32 +403,32 @@ class PropertiesTableView(QTableView):
                 # Show choice menu
                 menu.popup(QCursor.pos())
 
-    def Bezier_Action_Triggered(self, event):
-        log.info("Bezier_Action_Triggered")
+    def Bezier_Action_Triggered(self, preset=[]):
+        log.info("Bezier_Action_Triggered: %s" % str(preset))
         if self.property_type != "color":
             # Update keyframe interpolation mode
-            self.clip_properties_model.value_updated(self.selected_item, 0)
+            self.clip_properties_model.value_updated(self.selected_item, interpolation=0, interpolation_details=preset)
         else:
             # Update colors interpolation mode
-            self.clip_properties_model.color_update(self.selected_item, QColor("#000"), 0)
+            self.clip_properties_model.color_update(self.selected_item, QColor("#000"), interpolation=0, interpolation_details=preset)
 
     def Linear_Action_Triggered(self, event):
         log.info("Linear_Action_Triggered")
         if self.property_type != "color":
             # Update keyframe interpolation mode
-            self.clip_properties_model.value_updated(self.selected_item, 1)
+            self.clip_properties_model.value_updated(self.selected_item, interpolation=1)
         else:
             # Update colors interpolation mode
-            self.clip_properties_model.color_update(self.selected_item, QColor("#000"), 1)
+            self.clip_properties_model.color_update(self.selected_item, QColor("#000"), interpolation=1, interpolation_details=preset)
 
     def Constant_Action_Triggered(self, event):
         log.info("Constant_Action_Triggered")
         if self.property_type != "color":
             # Update keyframe interpolation mode
-            self.clip_properties_model.value_updated(self.selected_item, 2)
+            self.clip_properties_model.value_updated(self.selected_item, interpolation=2)
         else:
             # Update colors interpolation mode
-            self.clip_properties_model.color_update(self.selected_item, QColor("#000"), 2)
+            self.clip_properties_model.color_update(self.selected_item, QColor("#000"), interpolation=2, interpolation_details=preset)
 
     def Remove_Action_Triggered(self, event):
         log.info("Remove_Action_Triggered")
@@ -381,7 +453,10 @@ class PropertiesTableView(QTableView):
 
         # Keep track of mouse press start position to determine when to start drag
         self.selected = []
+        self.selected_label = None
         self.selected_item = None
+        self.new_value = None
+        self.original_data = None
 
         # Setup header columns
         self.setModel(self.clip_properties_model.model)
@@ -409,7 +484,7 @@ class PropertiesTableView(QTableView):
 
         # Connect filter signals
         get_app().window.txtPropertyFilter.textChanged.connect(self.filter_changed)
-        self.doubleClicked.connect(self.double_click)
+        self.doubleClicked.connect(self.doubleClickedCB)
         self.loadProperties.connect(self.select_item)
 
 
@@ -425,11 +500,21 @@ class SelectionLabel(QFrame):
 
         # Look up item for more info
         if self.item_type == "clip":
-            self.item_name = Clip.get(id=self.item_id).title()
+            item = Clip.get(id=self.item_id)
+            if item:
+                self.item_name = item.title()
         elif self.item_type == "transition":
-            self.item_name = Transition.get(id=self.item_id).title()
+            item = Transition.get(id=self.item_id)
+            if item:
+                self.item_name = item.title()
         elif self.item_type == "effect":
-            self.item_name = Effect.get(id=self.item_id).title()
+            item = Effect.get(id=self.item_id)
+            if item:
+                self.item_name = item.title()
+
+        # Bail if no item name was found
+        if not self.item_name:
+            return
 
         # Add selected clips
         for item_id in get_app().window.selected_clips:
@@ -507,16 +592,19 @@ class SelectionLabel(QFrame):
         # Look up item for more info
         if self.item_type == "clip":
             clip = Clip.get(id=self.item_id)
-            self.item_name = clip.title()
-            self.item_icon = QIcon(QPixmap(clip.data.get('image')))
+            if clip:
+                self.item_name = clip.title()
+                self.item_icon = QIcon(QPixmap(clip.data.get('image')))
         elif self.item_type == "transition":
             trans = Transition.get(id=self.item_id)
-            self.item_name = _(trans.title())
-            self.item_icon = QIcon(QPixmap(trans.data.get('reader', {}).get('path')))
+            if trans:
+                self.item_name = _(trans.title())
+                self.item_icon = QIcon(QPixmap(trans.data.get('reader', {}).get('path')))
         elif self.item_type == "effect":
             effect = Effect.get(id=self.item_id)
-            self.item_name = _(effect.title())
-            self.item_icon = QIcon(QPixmap(os.path.join(info.PATH, "effects", "icons", "%s.png" % effect.data.get('class_name').lower())))
+            if effect:
+                self.item_name = _(effect.title())
+                self.item_icon = QIcon(QPixmap(os.path.join(info.PATH, "effects", "icons", "%s.png" % effect.data.get('class_name').lower())))
 
         # Truncate long text
         if self.item_name and len(self.item_name) > 25:
